@@ -912,11 +912,7 @@ TEST_CASE("LP-modification", "[highs_data]") {
 
   // Attempting to set a cost to infinity may return error
   return_status = highs.changeColCost(7, kHighsInf);
-  if (kHighsAllowInfiniteCosts) {
-    REQUIRE(return_status == HighsStatus::kOk);
-  } else {
-    REQUIRE(return_status == HighsStatus::kError);
-  }
+  REQUIRE(return_status == HighsStatus::kOk);
 
   // Attempting to set a cost to a finite value returns OK
   REQUIRE(highs.changeColCost(7, 77) == HighsStatus::kOk);
@@ -1457,6 +1453,42 @@ TEST_CASE("LP-free-row", "[highs_data]") {
   REQUIRE(highs.getInfo().objective_function_value == -3);
 }
 
+TEST_CASE("LP-delete-ip-var", "[highs_data]") {
+  Highs highs;
+  highs.setOptionValue("output_flag", dev_run);
+  HighsInt num_var = 5;
+  std::vector<double> lower = {1, 2, 3, 4, 5};
+  std::vector<double> upper = {1, 2, 3, 4, 5};
+  highs.addVars(num_var, lower.data(), upper.data());
+  const HighsInt og_ip_var = 3;
+  const std::vector<HighsInt> og_ip_var_set = {og_ip_var};
+  const std::vector<HighsVarType> og_ip_var_integrality = {
+      HighsVarType::kInteger};
+  const HighsInt delete_var = 2;
+  const std::vector<HighsInt> delete_var_set = {delete_var};
+  const HighsInt later_ip_var = 2;
+  highs.changeColsIntegrality(1, og_ip_var_set.data(),
+                              og_ip_var_integrality.data());
+
+  for (HighsInt iCol = 0; iCol < num_var; iCol++) {
+    if (iCol == og_ip_var) {
+      REQUIRE(highs.getLp().integrality_[iCol] == HighsVarType::kInteger);
+    } else {
+      REQUIRE(highs.getLp().integrality_[iCol] == HighsVarType::kContinuous);
+    }
+  }
+  highs.deleteVars(1, delete_var_set.data());
+  // Now that #1386 is fixed, the integrality should be correct
+  num_var--;
+  for (HighsInt iCol = 0; iCol < num_var; iCol++) {
+    if (iCol == later_ip_var) {
+      REQUIRE(highs.getLp().integrality_[iCol] == HighsVarType::kInteger);
+    } else {
+      REQUIRE(highs.getLp().integrality_[iCol] == HighsVarType::kContinuous);
+    }
+  }
+}
+
 void HighsStatusReport(const HighsLogOptions& log_options, std::string message,
                        HighsStatus status) {
   if (!dev_run) return;
