@@ -51,7 +51,8 @@ public enum HighsModelStatus
     kTimeLimit,
     kIterationLimit,
     kUnknown,
-    kSolutionLimit
+    kSolutionLimit,
+    kInterrupt
 }
 
 public enum HighsIntegrality
@@ -1019,4 +1020,4 @@ public class SolutionInfo
     /// Gets or sets the objective value.
     /// </summary>
     public double ObjectiveValue { get; set; }
-}
\ No newline at end of file
+}
